WorkflowBuildError

Enum WorkflowBuildError 

#[non_exhaustive]
pub enum WorkflowBuildError {
Show 18 variants BlankWorkflowType, EmptySteps, BlankStepKey { step_index: Option<usize>, }, BlankStepJobType { step_key: String, }, BlankIdempotencyKey, BlankResultStepKey, UnknownResultStepKey { step_key: String, }, NonPositiveStepMaxAttempts { step_key: String, max_attempts: i32, }, NonPositiveStepTimeoutSeconds { step_key: String, timeout_seconds: i32, }, ExternalStepJobTypeNotAllowed { step_key: String, }, ExternalStepQueueSettingsNotAllowed { step_key: String, }, BlankDependencyStepKey { step_key: String, }, DuplicateStepKey { step_key: String, }, UnknownStepKey { step_key: String, }, MissingDependency { step_key: String, prerequisite_step_key: String, }, DuplicateDependency { step_key: String, prerequisite_step_key: String, }, SelfDependency { step_key: String, }, CycleDetected,
}
Error returned when building workflow enqueue payloads.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


BlankWorkflowType

The workflow type was blank.



EmptySteps

The workflow did not include any steps.



BlankStepKey

A step key was blank.

Fields

step_index: Option<usize>

The step index when the blank key came from a step list.



BlankStepJobType

A job step had a blank job type.

Fields

step_key: String

The step whose job type was blank.



BlankIdempotencyKey

The workflow idempotency key was blank.



BlankResultStepKey

The workflow result step key was blank.



UnknownResultStepKey

The workflow result step key does not match a step in the workflow.

Fields

step_key: String

The missing result step key.



NonPositiveStepMaxAttempts

A step max-attempts override was zero or negative.

Fields

step_key: String

The step with the invalid max-attempts override.

max_attempts: i32

The invalid max-attempts value.



NonPositiveStepTimeoutSeconds

A step timeout override was zero or negative.

Fields

step_key: String

The step with the invalid timeout override.

timeout_seconds: i32

The invalid timeout value in seconds.



ExternalStepJobTypeNotAllowed

An external step incorrectly supplied a job type.

Fields

step_key: String

The external step with a job type.



ExternalStepQueueSettingsNotAllowed

An external step incorrectly supplied queue execution settings.

Fields

step_key: String

The external step with queue settings.



BlankDependencyStepKey

A dependency prerequisite step key was blank.

Fields

step_key: String

The step that owns the blank dependency.



DuplicateStepKey

The workflow declared the same step key more than once.

Fields

step_key: String

The duplicate step key.



UnknownStepKey

Dependencies were attached to a step that has not been added to the builder.

Fields

step_key: String

The missing target step key.



MissingDependency

A dependency references a prerequisite step that does not exist in the workflow.

Fields

step_key: String

The step that owns the dependency.

prerequisite_step_key: String

The missing prerequisite step key.



DuplicateDependency

A step declares the same prerequisite more than once.

Fields

step_key: String

The step that owns the duplicate dependency.

prerequisite_step_key: String

The duplicated prerequisite step key.



SelfDependency

A step depends on itself.

Fields

step_key: String

The self-dependent step key.



CycleDetected

The workflow dependency graph contains a cycle.